@@ -20,7 +20,7 @@ from openstack.identity.v3 import region as _region
 from openstack.identity.v3 import service as _service
 from openstack.identity.v3 import trust as _trust
 from openstack.identity.v3 import user as _user
-from openstack import proxy
+from openstack import proxy2 as proxy
 
 
 class Proxy(proxy.BaseProxy):
