@@ -17,7 +17,7 @@ from openstack import resource
 class MeteringLabel(resource.Resource):
     resource_key = 'metering_label'
     resources_key = 'metering_labels'
-    base_path = '/metering-labels'
+    base_path = '/metering/metering-labels'
     service = network_service.NetworkService()
 
     # capabilities
@@ -34,3 +34,6 @@ class MeteringLabel(resource.Resource):
     name = resource.prop('name')
     #: The ID of the project this metering label is associated with.
     project_id = resource.prop('tenant_id')
+    #: Indicates whether this label is shared across all tenants.
+    #: *Type: bool*
+    is_shared = resource.prop('shared', type=bool)
