@@ -89,6 +89,8 @@ class Port(resource.Resource):
     #: The ID of the project who owns the network. Only administrative
     #: users can specify a project ID other than their own.
     project_id = resource.prop('tenant_id')
+    #: The ID of the QoS policy attached to the port.
+    qos_policy_id = resource.prop('qos_policy_id')
     #: The IDs of any attached security groups.
     #: *Type: list of strs of the security group IDs*
     security_group_ids = resource.prop('security_groups', type=list)
