@@ -152,9 +152,39 @@ class TestRouter(testtools.TestCase):
         response.json = mock.Mock(return_value=response.body)
         sess = mock.Mock()
         sess.put = mock.Mock(return_value=response)
-        body = {"port_id": "3"}
+        body = {"network_id": 3, "enable_snat": True}
         self.assertEqual(response.body, sot.remove_interface(sess, **body))
 
         url = 'routers/IDENTIFIER/remove_router_interface'
         sess.put.assert_called_with(url, endpoint_filter=sot.service,
                                     json=body)
+
+    def test_add_router_gateway(self):
+        # Add gateway to a router
+        sot = router.Router(EXAMPLE_WITH_OPTIONAL)
+        response = mock.Mock()
+        response.body = {"network_id": "3", "enable_snat": True}
+        response.json = mock.Mock(return_value=response.body)
+        sess = mock.Mock()
+        sess.put = mock.Mock(return_value=response)
+        body = {"network_id": 3, "enable_snat": True}
+        self.assertEqual(response.body, sot.add_gateway(sess, **body))
+
+        url = 'routers/IDENTIFIER/add_gateway_router'
+        sess.put.assert_called_with(url, endpoint_filter=sot.service,
+                                    json=body)
+
+    def test_remove_router_gateway(self):
+        # Remove gateway to a router
+        sot = router.Router(EXAMPLE_WITH_OPTIONAL)
+        response = mock.Mock()
+        response.body = {"network_id": "3", "enable_snat": True}
+        response.json = mock.Mock(return_value=response.body)
+        sess = mock.Mock()
+        sess.put = mock.Mock(return_value=response)
+        body = {"network_id": 3, "enable_snat": True}
+        self.assertEqual(response.body, sot.remove_gateway(sess, **body))
+
+        url = 'routers/IDENTIFIER/remove_gateway_router'
+        sess.put.assert_called_with(url, endpoint_filter=sot.service,
+                                    json=body)
